==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/OperatorSelectorClosingEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { OperatorSelectorClosingEventArgsDescription } from "./OperatorSelectorClosingEventArgsDescription";
/**
 * @hidden
 */
var OperatorSelectorClosingEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(OperatorSelectorClosingEventArgsDescriptionMetadata, _super);
    function OperatorSelectorClosingEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    OperatorSelectorClosingEventArgsDescriptionMetadata.b = function (a) {
        if (OperatorSelectorClosingEventArgsDescriptionMetadata.a == null) {
            OperatorSelectorClosingEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            OperatorSelectorClosingEventArgsDescriptionMetadata.c(OperatorSelectorClosingEventArgsDescriptionMetadata.a);
        }
        if (a.j(OperatorSelectorClosingEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(OperatorSelectorClosingEventArgsDescriptionMetadata.a);
    };
    OperatorSelectorClosingEventArgsDescriptionMetadata.c = function (a) {
    };
    OperatorSelectorClosingEventArgsDescriptionMetadata.d = function (a) {
        OperatorSelectorClosingEventArgsDescriptionMetadata.b(a);
        a.aa("OperatorSelectorClosingEventArgs", function () { return new OperatorSelectorClosingEventArgsDescription(); });
        a.z("OperatorSelectorClosingEventArgs", OperatorSelectorClosingEventArgsDescriptionMetadata.a);
    };
    OperatorSelectorClosingEventArgsDescriptionMetadata.$t = markType(OperatorSelectorClosingEventArgsDescriptionMetadata, 'OperatorSelectorClosingEventArgsDescriptionMetadata');
    OperatorSelectorClosingEventArgsDescriptionMetadata.a = null;
    return OperatorSelectorClosingEventArgsDescriptionMetadata;
}(Base));
export { OperatorSelectorClosingEventArgsDescriptionMetadata };

==> igniteui-react-core-18.1.3.tgz: package/esm5/lib/OperatorSelectorClosingEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { OperatorSelectorClosingEventArgsDescription } from "./OperatorSelectorClosingEventArgsDescription";
/**
 * @hidden
 */
var OperatorSelectorClosingEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(OperatorSelectorClosingEventArgsDescriptionMetadata, _super);
    function OperatorSelectorClosingEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    OperatorSelectorClosingEventArgsDescriptionMetadata.b = function (a) {
        if (OperatorSelectorClosingEventArgsDescriptionMetadata.a == null) {
            OperatorSelectorClosingEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            OperatorSelectorClosingEventArgsDescriptionMetadata.c(OperatorSelectorClosingEventArgsDescriptionMetadata.a);
        }
        if (a.k(OperatorSelectorClosingEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.aa(OperatorSelectorClosingEventArgsDescriptionMetadata.a);
    };
    OperatorSelectorClosingEventArgsDescriptionMetadata.c = function (a) {
    };
    OperatorSelectorClosingEventArgsDescriptionMetadata.d = function (a) {
        OperatorSelectorClosingEventArgsDescriptionMetadata.b(a);
        a.ac("OperatorSelectorClosingEventArgs", function () { return new OperatorSelectorClosingEventArgsDescription(); });
        a.ab("OperatorSelectorClosingEventArgs", OperatorSelectorClosingEventArgsDescriptionMetadata.a);
    };
    OperatorSelectorClosingEventArgsDescriptionMetadata.$t = markType(OperatorSelectorClosingEventArgsDescriptionMetadata, 'OperatorSelectorClosingEventArgsDescriptionMetadata');
    OperatorSelectorClosingEventArgsDescriptionMetadata.a = null;
    return OperatorSelectorClosingEventArgsDescriptionMetadata;
}(Base));
export { OperatorSelectorClosingEventArgsDescriptionMetadata };
